/*
 * Copyright (c) 2000 Dave Jones <dave@powertweak.com>
 *
 * Can be freely distributed and used under the terms of the GNU GPL.
 */

#include <gtk/gtk.h>
#include <stdio.h>
#include "powertweak.h"

#include "notebook.h"

GtkWidget *notebook;
GtkWidget *current_pages[MAX_POSSIBLE_PAGES];
gint current_max_page=0;

extern void clear_tweak_info(void);


GtkText *CreateText (char *buffer)
{
	GtkWidget *Text;

	Text = gtk_text_new (NULL, NULL);
	gtk_text_set_editable (GTK_TEXT (Text), FALSE);

	gtk_text_insert (GTK_TEXT(Text), NULL, NULL, NULL,
		buffer, strlen (buffer));
	gtk_widget_show (Text);

	return GTK_TEXT(Text);
}


/*
 * PageSwitch
 *
 * Event that occurs when a different page is now the focus.
 */
void PageSwitch (GtkWidget __unused *widget, GtkNotebookPage __unused *page, gint __unused page_num)
{
//FIXME: Should only be called if tweak_info is on a visible tab.
	//	clear_tweak_info();
}



/*
 * AddPage
 *
 * Add a page to the notebook 
 *
 * notebook - existing notebook
 * pagename - name to give to the new page
 */
void AddPage (GtkNotebook *notebook, char *pagename)
{
	GtkWidget *label;
	GtkWidget *frame;
	int i;

	/* --- Create a label from the name. --- */
	label = gtk_label_new (pagename);
	gtk_widget_show (label);

	/* --- Create a frame for the page --- */
	frame = gtk_frame_new (NULL);
	gtk_frame_set_shadow_type(GTK_FRAME (frame), GTK_SHADOW_NONE);
	gtk_widget_show (frame);

	/* --- Add a page with the frame and label --- */
	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, label);

	for (i=0;i<MAX_POSSIBLE_PAGES;i++) {
		if (current_pages[i]==NULL) {
			current_pages[i]=frame;
			current_max_page++;
			goto out;
		}
	}
out:
}


void remove_all_pages(GtkWidget *notebook)
{
	int i;

	if (current_max_page!=0) {
	  gtk_widget_hide (GTK_WIDGET(notebook));
	  for (i=0;i<MAX_POSSIBLE_PAGES;i++) {
	    if (current_pages[i]!=NULL) {
	      current_pages[i]=NULL;
	      current_max_page--;
	      gtk_notebook_remove_page(GTK_NOTEBOOK(notebook), 
				       -1);
	    }
	  }
	  gtk_widget_show (GTK_WIDGET(notebook));
	  gtk_widget_draw (GTK_WIDGET(notebook), NULL);
	}
	else printf ("Zoinks! maxpages was 0 !\n");

	//Debugging paranoia, to be removed sometime..
	if (current_max_page!=0) {
		printf ("Zoinks! maxpages wasn't 0 after removing all pages!\n");
	}
}


/*
 * CreateNotebookWindow
 *
 * Create a window to display the notebook.
 */
GtkWidget *CreateNotebook (GtkPositionType pos)
{
	notebook = gtk_notebook_new ();	/* Create the notebook*/
	gtk_signal_connect (GTK_OBJECT (notebook), "switch_page",
			GTK_SIGNAL_FUNC (PageSwitch), NULL);

	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), pos);

	gtk_container_border_width (GTK_CONTAINER (notebook), 10);
	return notebook;
}
