/*
 * Copyright (c) 2000 Dave Jones <dave@powertweak.com>
 *
 * Can be freely distributed and used under the terms of the GNU GPL.
 */

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <gtk/gtk.h>
#include <procxml.h>
#include "powertweak.h"

#define CONFIGFILENAME "/etc/sysctl.conf"

extern struct pci_access *pacc;

extern void show_popup(char *title, char *message);
extern char* getlocalesuffixed(char* filename);

int writeconfigfile(const char *configfilename)
{
	rh_list *rl = 0;
	char *buffer = 0;
	rhconfig_t *rhc = 0;

	rhc = ReadFile(configfilename, 0, 0, 0644);

	if(!rhc)
	  goto error;

	rl = Buf2List(rhc->buf); /*free(buffer); buffer = 0;*/

	save_XML(&rl, xmlroot);

	/* buffer = List2Buf(rl); rl = 0; */
	
	NewContent2(rhc, rl); rl = 0;

	if(WriteFile(rhc) != 0)
	  goto error;

	return (TRUE);

 error:
	if(rl)
	  rh_list_delete (rl, 1);

	if(buffer)
	  free(buffer);

	return(FALSE);
}


void savefunction (GtkWidget __unused *widget, gpointer __unused gdata)
{
	char error_message[]="Error trying to save to " CONFIGFILENAME;
	char saved_message[]="Configuration file saved to " CONFIGFILENAME;

	if (writeconfigfile(CONFIGFILENAME)==FALSE)
		show_popup ("Error!", error_message);
	else
		show_popup ("Done.", saved_message);
}


/*
 * The following routine sets everything up to use the current
 * values, by reading status from hardware/configfiles where appropriate
 */
void init_configfile(void)
{
	const char configfilename[]=CONFIGFILENAME;
	char *buffer = 0;
	rhconfig_t *rhc = 0;
	rh_list *rl = 0;

	/* Now for the /proc stuff. */
	if (xmlroot==NULL) 
		init_xml_subsystem_from_file(getlocalesuffixed(XMLFILE));


	rhc = ReadFile(configfilename, 0, 0, 0644);

	if(!rhc)
	  goto error;

	rl = Buf2List(rhc->buf); /*free(buffer); buffer = 0;*/

	init_XML_values(&rl, xmlroot);

	return;

 error:
	if(rl)
	  rh_list_delete (rl, 1);

	if(buffer)
	  free(buffer);   
}

