/* Copyright 2000 Red Hat, Inc.
 *
 * Florian La Roche <Florian.LaRoche@redhat.de>
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <sys/types.h>
#include <unistd.h>
#include <errno.h>
#include <stdlib.h>
#include <string.h>
#include "rhutil.h"
#include "backupfile.h"

static enum backup_type backup_type = numbered_existing;
static int init_done = 0;

static void
init_backups (void)
{
#if	0	/* XXX */
	const char *version_control;

	version_control = getenv ("RHCL_VERSION_CONTROL");
	if (version_control) {
		backup_type = get_version ("$RHCL_VERSION_CONTROL",
			version_control);
	} else if ((version_control = getenv ("VERSION_CONTROL"))) {
		backup_type = get_version ("$VERSION_CONTROL",
			version_control);
	}
#if 0
	/* XXX how can we look at the command line args? */
	case 'V':
		version_control = optarg;
		break;
#endif
#endif

	init_done = 1;
}

int
BackupFile (const char *name)
{
	char *backup;
	int err;

	if (! init_done)
		init_backups ();

	if (backup_type == none)
		return 0;

	backup = find_backup_file_name (name, backup_type);
	if (! backup)
		goto error;	/* no mem available */
	/* try to delete an already existing backup */
	if (unlink (backup) && errno != ENOENT)
		goto error;
	/* ignore if there is no file we can make a backup of */
	if (link (name, backup) && errno != ENOENT)
	  goto error;

	free (backup);
	return 0;

error:
	err = errno;
	RH_FREE (backup);
	errno = err;
	return -1;
}
