/* Copyright 1999 Red Hat, Inc.
 *
 * Florian La Roche <Florian.LaRoche@redhat.de>
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <errno.h>
#include <stdlib.h>
#include <stdio.h>
#include "rhutil.h"

ssize_t
Read (int fd, void *buf, size_t len)
{
	size_t l = len;
	char *b = buf;

	while (l > 0) {
		ssize_t err = read (fd, b, l);
		if (err == -1) {
			/* continue in case of signal interrupt */
			if (errno == EINTR || errno == EAGAIN)
				continue;
			return -1;	/* return -1 on any real error */
		} else if (err == 0)
			return len - l;	/* reached end of file */
		l -= err;
		b += err;
	}
	return len;
}
