/* Copyright 1999-2000 Red Hat, Inc.
 *
 * Florian La Roche <Florian.LaRoche@redhat.de>
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <errno.h>
#include <stdlib.h>
#include <stdio.h>
#include <limits.h>
#include "rhutil.h"

rhconfig_t *
ReadFile (const char *name, uid_t uid, gid_t gid, mode_t mode)
{
	int fd = -1;
	rhconfig_t *c = rh_xcalloc (sizeof *c);

	c->name = rh_xstrdup (name);
	c->st.st_uid = uid;
	c->st.st_gid = gid;
	c->st.st_mode = mode;
	if ((fd = open (name, O_RDONLY)) < 0 || fstat (fd, &c->st))
		goto error;
	/* check for a maximum size of a file. c->st.st_size is off_t and
	   not only size_t. */
	if (c->st.st_size >= SSIZE_MAX)
		goto error;
	c->n = c->st.st_size;
	c->buf = rh_xmalloc (c->n + 1);
	if (Read (fd, c->buf, c->st.st_size) < 0)
		goto error;
	c->buf[c->n] = '\0';
	(void) close (fd);
	return c;

error:
	if (fd != -1)
		(void) close (fd);
	RH_FREE (c->buf);
	free (c->name);
	free (c);
	return NULL;
}

void
FreeFile (rhconfig_t *c)
{
	free (c->name);
	RH_FREE (c->buf);
}
